@@ -1029,9 +1029,7 @@ json_create_handle_unknown_type (json_create_t * jc, SV * r)
 
 #define STRICT_NO_SCALAR						\
     if (jc->strict) {							\
-	json_create_user_message (jc, json_create_scalar_reference,	\
-				  "Scalar reference rejected");		\
-	return json_create_scalar_reference;				\
+	goto handle_type;						\
     }
 
 
@@ -1088,6 +1086,7 @@ json_create_handle_ref (json_create_t * jc, SV * input)
 	break;
 
     default:
+    handle_type:
 	CALL (json_create_handle_unknown_type (jc, r));
     }
     return json_create_ok;
