@@ -1,13 +1,13 @@
 package JSON::Create;
 require Exporter;
 @ISA = qw(Exporter);
-@EXPORT_OK = qw/create_json/;
+@EXPORT_OK = qw/create_json create_json_strict/;
 %EXPORT_TAGS = (
     all => \@EXPORT_OK,
 );
 use warnings;
 use strict;
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 # Are we running as XS?
 our $noxs;
 $noxs = $ENV{JSONCreatePP};
